/*
 * Copyright (c) 2017, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

import UIKit
import CoreBluetooth
import AVFoundation

class ButtonServiceViewController: UIViewController
{

    // MARK: Properties
    @IBOutlet weak var buttonS1: UIImageView!
    @IBOutlet weak var buttonS2: UIImageView!
    @IBOutlet weak var instructionsLabel: UILabel!
    @IBOutlet weak var s1Label: UILabel!
    @IBOutlet weak var s2Label: UILabel!
    @IBOutlet weak var stackView: UIStackView!
    
    // MARK: Variables
    let s1SoundURL =  Bundle.main.url(forResource: "1khz",
                                      withExtension: "mp3")!
    let s2SoundURL =  Bundle.main.url(forResource: "440hz",
                                      withExtension: "mp3")!
    var s1EffectPlayer = AVAudioPlayer()
    var s2EffectPlayer = AVAudioPlayer()
    var writingValue = false
    var debounceTimer =  Timer()
    var referencedController: ProjectZeroTabBarController!
    
    override func viewDidLoad()
    {
        super.viewDidLoad()

        referencedController = tabBarController as! ProjectZeroTabBarController
        referencedController.buttonServiceController = self
        
        /* Adding observer to rotate view */
        NotificationCenter.default.addObserver(self,
                                               selector: #selector(ButtonServiceViewController.viewRotated),
                                               name: NSNotification.Name.UIDeviceOrientationDidChange, object: nil)
    }

    override func didReceiveMemoryWarning()
    {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
    
    @objc func viewRotated()
    {
        DispatchQueue.main.async
            {
                if UIDeviceOrientationIsPortrait(UIDevice.current.orientation)
                {
                    self.s2Label.isHidden = false
                    self.s1Label.isHidden = false
                    self.instructionsLabel.isHidden = false
                }
                
                if UIDeviceOrientationIsLandscape(UIDevice.current.orientation)
                {
                    self.s2Label.isHidden = true
                    self.s1Label.isHidden = true
                    self.instructionsLabel.isHidden = true
                }
        }
    }

}
