import UIKit
import Charts
import CoreBluetooth

class MagViewController: UIViewController
{
    // MARK: Variables
    var referencedController: SensorTabBarController!
    var lineChartDataSetX: LineChartDataSet!
    var lineChartDataSetY: LineChartDataSet!
    var lineChartDataSetZ: LineChartDataSet!
    var lineChartData: LineChartData!
    var xDataEntries: [ChartDataEntry] = []
    var yDataEntries: [ChartDataEntry] = []
    var zDataEntries: [ChartDataEntry] = []
    var curIndex = 0
    
    // MARK: Properties
    @IBOutlet weak var graphView: LineChartView!
    @IBOutlet weak var valLabel: UILabel!
    
    // MARK: Functions
    func adjustChartFormat()
    {
        lineChartDataSetX.setCircleColor(UIColor.black)
        lineChartDataSetX.circleRadius = 1.0
        lineChartDataSetX.drawCircleHoleEnabled = false
        lineChartDataSetX.drawValuesEnabled = false
        
        lineChartDataSetY.setCircleColor(UIColor.black)
        lineChartDataSetY.circleRadius = 1.0
        lineChartDataSetY.drawCircleHoleEnabled = false
        lineChartDataSetY.drawValuesEnabled = false
        
        lineChartDataSetZ.setCircleColor(UIColor.black)
        lineChartDataSetZ.circleRadius = 1.0
        lineChartDataSetZ.drawCircleHoleEnabled = false
        lineChartDataSetZ.drawValuesEnabled = false
        
        lineChartData = LineChartData()
        lineChartData.addDataSet(lineChartDataSetX)
        lineChartData.addDataSet(lineChartDataSetY)
        lineChartData.addDataSet(lineChartDataSetZ)
        
        graphView.data = lineChartData
        
        /* Adjusting the Margins */
        graphView.leftAxis.axisMaximum = Double(INT16_MAX)
        graphView.leftAxis.axisMinimum = Double(INT16_MIN)
        
        let xAxis = graphView.xAxis
        xAxis.enabled = false
        
        graphView.chartDescription?.text = "Magnetic Data"
        
    }
    
    func addGraphValue(intValX: Int16, intValY: Int16, intValZ: Int16)
    {
        if (curIndex == 0)
        {
            lineChartDataSetX = LineChartDataSet(values: xDataEntries,
                                                 label: "X")
            lineChartDataSetX.setColor(UIColor.red)
            lineChartDataSetY = LineChartDataSet(values: yDataEntries,
                                                 label: "Y")
            lineChartDataSetY.setColor(UIColor.blue)
            lineChartDataSetZ = LineChartDataSet(values: zDataEntries,
                                                 label: "Z")
            lineChartDataSetZ.setColor(UIColor.green)
            adjustChartFormat()
        }
        
        let dataEntryX = ChartDataEntry(x: Double(curIndex),
                                        y: Double(intValX))
        let dataEntryY = ChartDataEntry(x: Double(curIndex),
                                        y: Double(intValY))
        let dataEntryZ = ChartDataEntry(x: Double(curIndex),
                                        y: Double(intValZ))
        
        if(curIndex == SENSOR_GRAPH_SAMPLES)
        {
            _ = lineChartDataSetX.removeFirst()
            _ = lineChartDataSetY.removeFirst()
            _ = lineChartDataSetZ.removeFirst()
            
            for dataValue in lineChartDataSetX.values
            {
                dataValue.x = dataValue.x - 1
            }
            
            for dataValue in lineChartDataSetY.values
            {
                dataValue.x = dataValue.x - 1
            }
            
            for dataValue in lineChartDataSetZ.values
            {
                dataValue.x = dataValue.x - 1
            }
            
        }
        else
        {
            curIndex = curIndex + 1
        }
        
        _ = lineChartDataSetX.addEntry(dataEntryX)
        _ = lineChartDataSetY.addEntry(dataEntryY)
        _ = lineChartDataSetZ.addEntry(dataEntryZ)
        
        
        lineChartData.notifyDataChanged()
        graphView.notifyDataSetChanged()
        
        valLabel.text = "X: " + String(intValX) + "\nY: " + String(intValY) +
            "\nZ: " + String(intValZ)
        
    }
    
    @objc func viewRotated()
    {
        DispatchQueue.main.async
            {
                if UIDeviceOrientationIsPortrait(UIDevice.current.orientation)
                {
                    self.valLabel.isHidden = false
                }
                else if UIDeviceOrientationIsLandscape(UIDevice.current.orientation)
                {
                    self.valLabel.isHidden = true
                }
        }
    }
    
    override func viewDidLoad()
    {
        super.viewDidLoad()
        referencedController = tabBarController as! SensorTabBarController
        referencedController.magGraphController = self
        valLabel.adjustsFontSizeToFitWidth = true
        
        /* Adding observer to rotate view */
        NotificationCenter.default.addObserver(self,
                                               selector: #selector(MagViewController.viewRotated),
                                               name: NSNotification.Name.UIDeviceOrientationDidChange, object: nil)
        viewRotated()
    }
    
    override func didReceiveMemoryWarning()
    {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
    
    
}
