/*
 * Copyright (c) 2017, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

import UIKit

class ProvisionSummaryViewController: UIViewController
{
    // MARK: Properties
    @IBOutlet weak var ssidSLLabel: UILabel!
    @IBOutlet weak var keySLLabel: UILabel!
    @IBOutlet weak var ssidRTLabel: UILabel!
    @IBOutlet weak var keyRTLabel: UILabel!
    @IBOutlet weak var provisionButton: UIButton!
    @IBOutlet weak var devNameLabel: UILabel!
    @IBOutlet weak var instructionBox: UILabel!
    @IBOutlet weak var devBox: UILabel!
    @IBOutlet weak var devInfoBox: UIView!
    @IBOutlet weak var routerBox: UILabel!
    @IBOutlet weak var routerInfoBox: UIView!
    @IBOutlet weak var keyTypeField: UILabel!
    @IBOutlet weak var routerKeyTypeField: UILabel!
    
    // MARK: Variables
    var curSettings = WiFiSettings()
    
    // MARK: Actions
    @IBAction func provisionPressed(_ sender: Any)
    {
        self.performSegue(withIdentifier: "startProvisionSegue", sender: self)
    }
    
    @IBAction func startBarItemPressed(_ sender: Any)
    {
        self.performSegue(withIdentifier: "startProvisionSegue", sender: nil)
    }

    @IBAction func cancelBarItemPressed(_ sender: Any)
    {
        self.navigationController?.popViewController(animated: true)
    }
    
    // MARK: Functions
    override func prepare(for segue: UIStoryboardSegue, sender: Any?)
    {
        if(segue.identifier == "startProvisionSegue")
        {
            let provStart: WiFiDirectProvisionViewController =
                segue.destination as! WiFiDirectProvisionViewController
            provStart.curSettings = self.curSettings
        }
    }
    
    override func viewDidLoad()
    {
        super.viewDidLoad()
        
        /* Setting up the GUI a bit */
        provisionButton.clipsToBounds = true
        provisionButton.layer.cornerRadius = 8.0
        ssidRTLabel.text = curSettings.routerName
        instructionBox.clipsToBounds = true
        instructionBox.layer.cornerRadius = 8.0
        devBox.clipsToBounds = true
        devBox.layer.cornerRadius = 8.0
        devInfoBox.clipsToBounds = true
        devInfoBox.layer.cornerRadius = 8.0
        routerBox.clipsToBounds = true
        routerBox.layer.cornerRadius = 8.0
        routerInfoBox.clipsToBounds = true
        routerInfoBox.layer.cornerRadius = 8.0
        
        if(curSettings.routerKey.isEmpty)
        {
            keyRTLabel.text = "None"
        }
        else
        {
            keyRTLabel.text = curSettings.routerKey
        }
        
        ssidSLLabel.text = curSettings.simplelinkName
        devNameLabel.text = curSettings.devName
        
        if(curSettings.simplelinkKey.isEmpty)
        {
            keySLLabel.text = "None"
        }
        else
        {
            keySLLabel.text = curSettings.simplelinkKey
        }
        
        keyTypeField.text = curSettings.devSecType.rawValue
        routerKeyTypeField.text = curSettings.routerSecType.rawValue

        /* Adding observer to rotate view */
        NotificationCenter.default.addObserver(self,
                                               selector: #selector(ProvisionSummaryViewController.viewRotated),
                                               name: NSNotification.Name.UIDeviceOrientationDidChange, object: nil)
    }
    
    override func viewWillAppear(_ animated: Bool)
    {
        
    }
    
    override func viewWillDisappear(_ animated: Bool)
    {
        /* Removin observer to center the text */
        super.viewWillDisappear(animated)
    }

    override func didReceiveMemoryWarning()
    {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
    
    @objc func viewRotated()
    {
        DispatchQueue.main.async
            {
                if UIDeviceOrientationIsPortrait(UIDevice.current.orientation)
                {
                    self.instructionBox.isHidden = false
                    self.provisionButton.isHidden = false
                }
                
                if UIDeviceOrientationIsLandscape(UIDevice.current.orientation)
                {
                    self.instructionBox.isHidden = true
                    self.provisionButton.isHidden = true
                }
        }
    }

}
