import UIKit

private let reuseIdentifier = "SensorCell"

class SensorCollectionViewController: UICollectionViewController
{
    
    // MARK: Sensor Objects
    let sensorObjects =
        [
            SensorHubSensor(displayImage: UIImage(named: "thermometer")!,
                            description: "Temperature", units: "°C"),
            SensorHubSensor(displayImage: UIImage(named: "humidity")!,
                            description: "Humidity", units: "%"),
            SensorHubSensor(displayImage: UIImage(named: "optical")!,
                            description: "Optical", units: " lux"),
            SensorHubSensor(displayImage: UIImage(named: "barometer")!,
                            description: "Pressure", units: " kPa"),
            SensorHubMovementSensor(displayImage: UIImage(named: "accelerometer")!,
                            description: "Movement", units: "X"),
            SensorHubMovementSensor(displayImage: UIImage(named: "gyrometer")!,
                                    description: "Position", units: "X"),
            SensorHubMovementSensor(displayImage: UIImage(named: "magnometer")!,
                                    description: "Magnet", units: "X"),
            
        ]
    
    // MARK: Variables
    var referencedController: SensorTabBarController!
    
    // MARK: Functions
    func addSensorData(sensor: String, data: Float) -> SensorStatistics
    {
        var stats: SensorStatistics!
        
        for curSensor in sensorObjects
        {
            if(curSensor.description == sensor)
            {
                curSensor.addSensorValue(val: data)
                stats = curSensor.sensorStatistics
            }
        }
        
        collectionView?.reloadData()
        return stats
        
    }
    
    func addMovementSensorData(sensor: String, data: [Int16])
    {
        for ii in 4...(sensorObjects.count-1)
        {
            let curSensor = sensorObjects[ii] as! SensorHubMovementSensor
            
            if(curSensor.sensorName == sensor)
            {
                curSensor.addSensorValueMovement(val: data)
            }
        
        }
        
        collectionView?.reloadData()
    }
    
    
    // MARK: Navigation
    override func viewDidLoad()
    {
        super.viewDidLoad()
        referencedController = tabBarController as! SensorTabBarController
        referencedController.sensorOverViewController = self
    }

    override func didReceiveMemoryWarning()
    {
        super.didReceiveMemoryWarning()
    }

    /*
    // MARK: - Navigation

    // In a storyboard-based application, you will often want to do a little preparation before navigation
    override func prepare(for segue: UIStoryboardSegue, sender: Any?) {
        // Get the new view controller using [segue destinationViewController].
        // Pass the selected object to the new view controller.
    }
    */

    // MARK: UICollectionViewDataSource

    override func numberOfSections(in collectionView: UICollectionView) -> Int
    {
        return 1
    }

    override func collectionView(_ collectionView: UICollectionView, numberOfItemsInSection section: Int) -> Int
    {
        return sensorObjects.count
    }

    override func collectionView(_ collectionView: UICollectionView, cellForItemAt indexPath: IndexPath) -> UICollectionViewCell
    {
        let cell = collectionView.dequeueReusableCell(withReuseIdentifier: reuseIdentifier,
                                                      for: indexPath) as! SensorCollectionViewCell
        
        if(indexPath.row < 4)
        {
            let curSensor = sensorObjects[indexPath.row]
            cell.sensorImage.image = curSensor.displayImage
            cell.sensorTitle.text = curSensor.description
            cell.sensorValue.text = curSensor.getFormattedLatestReading()
            cell.sensorValue.adjustsFontSizeToFitWidth = true
        }
        else
        {
            let curSensor = sensorObjects[indexPath.row] as! SensorHubMovementSensor
            cell.sensorImage.image = curSensor.displayImage
            cell.sensorTitle.text = curSensor.description
            cell.sensorValue.text = curSensor.getFormatedLatestReadingMovement()
            cell.sensorValue.adjustsFontSizeToFitWidth = true
        }
    
        return cell
    }

    // MARK: UICollectionViewDelegate

    /*
    // Uncomment this method to specify if the specified item should be highlighted during tracking
    override func collectionView(_ collectionView: UICollectionView, shouldHighlightItemAt indexPath: IndexPath) -> Bool 
    {
        return true
    }
    */

    /*
    // Uncomment this method to specify if the specified item should be selected
    override func collectionView(_ collectionView: UICollectionView, shouldSelectItemAt indexPath: IndexPath) -> Bool {
        return true
    }
    */

    /*
    // Uncomment these methods to specify if an action menu should be displayed for the specified item, and react to actions performed on the item
    override func collectionView(_ collectionView: UICollectionView, shouldShowMenuForItemAt indexPath: IndexPath) -> Bool {
        return false
    }

    override func collectionView(_ collectionView: UICollectionView, canPerformAction action: Selector, forItemAt indexPath: IndexPath, withSender sender: Any?) -> Bool {
        return false
    }

    override func collectionView(_ collectionView: UICollectionView, performAction action: Selector, forItemAt indexPath: IndexPath, withSender sender: Any?) 
    {
    
    }
    */
    
    // MARK: Functions

}
