import UIKit

struct SensorStatistics
{
    var min: Float = 0.0
    var max: Float = 0.0
    var avg: Float = 0.0
}

class SensorHubSensor: NSObject
{
    // MARK: Variables
    var displayImage: UIImage!
    var sensorName = "Sensor"
    var sensorReadings: [Float] = []
    var units = ""
    var formatString: String
    let maxSamples = 10
    
    override var description: String
    {
        return "\(self.sensorName)"
    }
    
    var sensorStatistics: SensorStatistics
    {
        if(sensorReadings.isEmpty)
        {
            return SensorStatistics(min: 0, max: 0, avg: 0)
        }
        
        var curSum: Float = 0.0
        
        for sensorValue in sensorReadings
        {
            curSum += sensorValue
        }
        
        return SensorStatistics(min: sensorReadings.min()!,
                                max: sensorReadings.max()!,
                                avg: curSum/Float(sensorReadings.count))
    
    }
    
    init(displayImage: UIImage, description: String, units: String, formatString: String = "%.1f")
    {
        self.displayImage = displayImage
        self.sensorName = description
        self.units = units
        self.formatString = formatString
    }
    
    func addSensorValue(val: Float)
    {
        if(sensorReadings.count == maxSamples)
        {
            sensorReadings.remove(at: 0)
        }

        sensorReadings.append(val)
    }
    
    func getLatestReading() -> Float
    {
        if(!sensorReadings.isEmpty)
        {
            return sensorReadings[sensorReadings.count-1]
        }
        else
        {
            return 0.0
        }
    }
    
    func getFormattedLatestReading() -> String
    {
        return String(format: formatString, self.getLatestReading()) + self.units
    }

}
